@@ -38,10 +38,11 @@ package Dist::Zilla::PluginBundle::Author::VDB;
 
 use Moose;
 use namespace::autoclean;
+use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.5'; # VERSION
+our $VERSION = 'v0.8.6'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -324,6 +325,9 @@ sub configure {
     my ( $self ) = @_;
     our $Self = $self;                  ## no critic ( ProhibitPackageVars )
 
+    require Dist::Zilla::Plugin::Manifest::Write;
+        # Make sure the plugin is loaded before checking its version.
+
     $self->add_plugins(
 
         [ 'Hook' => 'prologue' => {
@@ -424,11 +428,28 @@ sub configure {
         ) : (
         ),
 
-        [ 'Manifest::Write' => {
-            'source_providers' => [
-                'Manifest::Read',
-                'GenerateFile',
-            ],
+        [ 'Manifest::Write' => { # REQUIRE: v0.9.0
+            # `Manifest::Write` v0.9.0 strictly requires plugin names, not monikers.
+            # If a plugin name is added from the bundle, `PluginBundle::Easy` prepends its name
+            # with the bundle name (or moniker?).
+            Dist::Zilla::Plugin::Manifest::Write->VERSION() < version->parse( 'v0.9.0' ) ? (
+                'source_providers' => [
+                    'Manifest::Read',
+                    'GenerateFile',
+                ],
+            ) : (
+                'source_provider' => [
+                    '@Author::VDB/Manifest::Read',
+                    $self->copying ne '' ? '@Author::VDB/COPYING' : (),
+                    $self->readme        ? '@Author::VDB/README'  : (),
+                ],
+                'metainfo_provider' => [
+                    # Defaults are not suitable because they are just `MetaJSON` and `MetaYAML`.
+                    '@Author::VDB/Manifest::Write',
+                    '@Author::VDB/MetaJSON',
+                    '@Author::VDB/MetaYAML',
+                ],
+            ),
         } ],
 
         #
@@ -936,7 +957,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.5, released on 2015-09-27 13:43 UTC.
+Version v0.8.6, released on 2015-10-03 10:53 UTC.
 
 =head1 WHAT?
 
